<?php

namespace Drupal\commerce_vado\Plugin\Commerce\VadoGroupWidget;

use Drupal\commerce\EntityHelper;
use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Plugin\PluginBase;

/**
 * Provides the base class for vado group widgets.
 */
abstract class VadoGroupWidgetBase extends PluginBase implements VadoGroupWidgetInterface {

  /**
   * The group the plugin instance belongs to.
   *
   * @var \Drupal\commerce_vado\Entity\VadoGroupInterface
   */
  protected $parentEntity;

  /**
   * {@inheritdoc}
   */
  public function setParentEntity(EntityInterface $parent_entity) {
    $this->parentEntity = $parent_entity;
  }

  /**
   * {@inheritdoc}
   */
  public function getLabel() {
    return $this->pluginDefinition['label'];
  }

  /**
   * {@inheritdoc}
   */
  public function allowsMultiple() {
    return $this->pluginDefinition['allows_multiple'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildElement(array $form, FormStateInterface $form_state) {
    return [];
  }

  /**
   * {@inheritdoc}
   */
  public function getDefaultValue() {
    $has_default_items = $this->parentEntity->hasDefaultItems();
    $default_items = $this->parentEntity->getDefaultItems();
    // multi-value elements expect an array of ids or an empty array.
    if ($this->allowsMultiple()) {
      return $has_default_items ? EntityHelper::extractIds($default_items) : [];
    }
    // single value elements expect a single id or NULL;
    else {
      return $has_default_items ? reset($default_items)->id() : NULL;
    }
  }

  /**
   * @return bool
   */
  protected function showEmptyOption() {
    return !$this->parentEntity->hasDefaultItems() || !$this->parentEntity->isRequired();
  }

  /**
   * @return bool
   */
  protected function shouldBuildEmptyOption() {
    return $this->showEmptyOption();
  }

  /**
   * @return array
   */
  protected function buildEmptyOption() {
    return ['' => $this->t('- None -')];
  }

  /**
   * @return array
   */
  protected function buildGroupItemOptions() {
    $addon_group_options = [];

    if ($this->shouldBuildEmptyOption()) {
      $addon_group_options += $this->buildEmptyOption();
    }
    foreach($this->parentEntity->getItems() as $group_item) {
      $addon_group_options[$group_item->id()] = $group_item->label();
    }

    return $addon_group_options;
  }

}
